%define major     11
%define libname   %mklibname %{name}_ %{major}
%define develname %mklibname %{name} -d
%define upversion 2024-07-02

Name:           re2
Version:        20240702
Release:        %mkrel 4
Summary:        C++ fast alternative to backtracking RE engines
Group:          System/Libraries
License:        BSD
URL:            https://github.com/google/re2/
Source0:        https://github.com/google/re2/archive/%{upversion}/%{name}-%{upversion}.tar.gz
BuildRequires:  cmake
BuildRequires:  cmake(absl)
BuildRequires:  pkgconfig(benchmark)
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(icu-uc)

%description
RE2 is a C++ library providing a fast, safe, thread-friendly alternative to
backtracking regular expression engines like those used in PCRE, Perl, and
Python.

Backtracking engines are typically full of features and convenient syntactic
sugar but can be forced into taking exponential amounts of time on even small
inputs.

In contrast, RE2 uses automata theory to guarantee that regular expression
searches run in time linear in the size of the input, at the expense of some
missing features (e.g back references and generalized assertions).

%package -n     %{libname}
Summary:        Library for %{name}
Group:          System/Libraries

%description -n %{libname}
RE2 is a C++ library providing a fast, safe, thread-friendly alternative to
backtracking regular expression engines like those used in PCRE, Perl, and
Python.

Backtracking engines are typically full of features and convenient syntactic
sugar but can be forced into taking exponential amounts of time on even small
inputs.

In contrast, RE2 uses automata theory to guarantee that regular expression
searches run in time linear in the size of the input, at the expense of some
missing features (e.g back references and generalized assertions).

%package -n     %{develname}
Summary:        C++ header files and library symbolic links for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains the C++ header files and symbolic links to the shared
libraries for %{name}. If you would like to develop programs using %{name},
you will need to install %{develname}.


%prep
%setup -q -n %{name}-%{upversion}
%autopatch -p1

%build
%cmake \
    -DBUILD_SHARED_LIBS=ON \
    -DRE2_USE_ICU=ON
%cmake_build

%install
%cmake_install

%check
%make_build shared-test

%files -n %{libname}
%doc README
%license LICENSE
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{develname}
%doc CONTRIBUTING.md
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/%{name}/


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 20240702-4.mga10
+ Revision: 2243721
- Mageia 10 Mass Rebuild

* Sun Mar 09 2025 wally <wally> 20240702-3.mga10
+ Revision: 2162132
- rebuild for abseil-cpp 20250127.0

* Sun Jan 12 2025 wally <wally> 20240702-2.mga10
+ Revision: 2138407
- rebuild for icu 76.1

* Wed Jul 10 2024 daviddavid <daviddavid> 20240702-1.mga10
+ Revision: 2080481
- new version: 20240702

* Wed Jun 05 2024 daviddavid <daviddavid> 20240601-1.mga10
+ Revision: 2070114
- new version: 20240601

* Sat May 25 2024 cjw <cjw> 20240501-2.mga10
+ Revision: 2067634
- rebuild for abseil
- add build dep on libbenchmark

* Sat May 04 2024 daviddavid <daviddavid> 20240501-1.mga10
+ Revision: 2062096
- new version: 20240501

* Tue Apr 02 2024 daviddavid <daviddavid> 20240401-1.mga10
+ Revision: 2053773
- new version: 20240401

* Mon Mar 11 2024 daviddavid <daviddavid> 20240301-1.mga10
+ Revision: 2049113
- new version: 20240301

* Fri Feb 09 2024 daviddavid <daviddavid> 20240201-1.mga10
+ Revision: 2039879
- new version: 20240201

* Wed Nov 01 2023 daviddavid <daviddavid> 20231101-3.mga10
+ Revision: 2003441
- new version: 20231101

* Thu Sep 28 2023 tv <tv> 20230901-3.mga10
+ Revision: 1992022
- Rebuild for icu-73

* Sat Sep 23 2023 daviddavid <daviddavid> 20230901-2.mga10
+ Revision: 1989490
- rebuild for new abseil-cpp 20230802.0

* Wed Sep 06 2023 daviddavid <daviddavid> 20230901-1.mga10
+ Revision: 1984829
- new version: 20230901
- now libmajor is 11
- switch to cmake build system
- new version: 20221201

* Mon Aug 22 2022 papoteur <papoteur> 20220601-1.mga9
+ Revision: 1879253
- new 20220601

* Tue Mar 15 2022 umeabot <umeabot> 20210801-2.mga9
+ Revision: 1793637
- Mageia 9 Mass Rebuild

* Sun Aug 08 2021 luigiwalser <luigiwalser> 20210801-1.mga9
+ Revision: 1740281
- 20210801

* Wed Apr 07 2021 daviddavid <daviddavid> 20210401-1.mga9
+ Revision: 1713931
- new version: 20210401

* Fri Feb 26 2021 daviddavid <daviddavid> 20210202-1.mga9
+ Revision: 1691918
- new version: 20210202

* Mon Dec 07 2020 cjw <cjw> 20201101-2.mga8
+ Revision: 1654094
- remove re2-symbols-fix.patch - the fix is not needed anymore and it now breaks other symbols

* Wed Dec 02 2020 luigiwalser <luigiwalser> 20201101-1.mga8
+ Revision: 1651775
- new version 20201101
- library major is now 9
- rediff symbols patch

* Thu Oct 22 2020 daviddavid <daviddavid> 20201001-1.mga8
+ Revision: 1638550
- new version: 20201001

* Tue Jul 14 2020 daviddavid <daviddavid> 20200706-1.mga8
+ Revision: 1605926
- new version: 20200706
- now libmajor is 8

* Wed Jun 03 2020 daviddavid <daviddavid> 20200601-1.mga8
+ Revision: 1590156
- new version: 20200601
- now libmajor is 7
- new version: 20200501

* Sun Apr 05 2020 daviddavid <daviddavid> 20200401-1.mga8
+ Revision: 1564816
- new version: 20200401
- now libmajor is 6
- new version: 20200302
- now libmajor is 1

* Wed Feb 19 2020 umeabot <umeabot> 20200101-2.mga8
+ Revision: 1543472
- Mageia 8 Mass Rebuild

* Mon Jan 20 2020 daviddavid <daviddavid> 20200101-1.mga8
+ Revision: 1481766
- new version: 20200101

* Mon Dec 02 2019 daviddavid <daviddavid> 20191201-1.mga8
+ Revision: 1464060
- new version: 20191201

* Fri Nov 08 2019 daviddavid <daviddavid> 20191101-1.mga8
+ Revision: 1458808
- new version: 20191101

* Fri Sep 13 2019 daviddavid <daviddavid> 20190901-1.mga8
+ Revision: 1440165
- new version: 20190901

* Sat Aug 03 2019 daviddavid <daviddavid> 20190801-1.mga8
+ Revision: 1426999
- new version: 20190801

* Fri Jul 05 2019 daviddavid <daviddavid> 20190701-1.mga8
+ Revision: 1418633
- new version: 20190701

* Sun Jun 30 2019 daviddavid <daviddavid> 20190601-1.mga8
+ Revision: 1416340
- new version: 20190601

* Wed Apr 03 2019 daviddavid <daviddavid> 20190401-1.mga7
+ Revision: 1385493
- new version: 20190401

* Sat Mar 02 2019 daviddavid <daviddavid> 20190301-1.mga7
+ Revision: 1370980
- new version: 20190301

* Sat Jan 12 2019 daviddavid <daviddavid> 20190101-1.mga7
+ Revision: 1355566
- new version: 20190101

* Sun Dec 02 2018 daviddavid <daviddavid> 20181201-1.mga7
+ Revision: 1337611
- new version: 20181201

* Mon Oct 01 2018 daviddavid <daviddavid> 20181001-1.mga7
+ Revision: 1313151
- new version: 20181001

* Sun Sep 23 2018 umeabot <umeabot> 20180801-2.mga7
+ Revision: 1300793
- Mageia 7 Mass Rebuild

* Fri Aug 03 2018 daviddavid <daviddavid> 20180801-1.mga7
+ Revision: 1246982
- new version: 20180801

* Sat Jul 07 2018 daviddavid <daviddavid> 20180701-1.mga7
+ Revision: 1242406
- new version: 20180701
+ wally <wally>
- drop unneeded -std=gnu++11 from CXXFLAGS

* Wed Apr 04 2018 daviddavid <daviddavid> 20180401-1.mga7
+ Revision: 1215120
- new version: 20180401

* Sat Mar 03 2018 daviddavid <daviddavid> 20180301-1.mga7
+ Revision: 1206190
- new version: 20180301

* Fri Feb 02 2018 daviddavid <daviddavid> 20180201-1.mga7
+ Revision: 1198645
- new version: 20180201

* Thu Jan 04 2018 daviddavid <daviddavid> 20180101-1.mga7
+ Revision: 1190197
- new version: 20180101

* Wed Dec 06 2017 daviddavid <daviddavid> 20171201-1.mga7
+ Revision: 1181523
- new version: 20171201

* Fri Nov 03 2017 daviddavid <daviddavid> 20171101-1.mga7
+ Revision: 1175640
- new version: 20171101

* Mon Aug 07 2017 daviddavid <daviddavid> 20170801-1.mga7
+ Revision: 1138269
- new version: 20170801

* Wed Jul 19 2017 daviddavid <daviddavid> 20170701-1.mga7
+ Revision: 1125039
- new version: 20170701
- rebase re2-symbols-fix patch

* Tue Apr 12 2016 daviddavid <daviddavid> 20160401-1.mga6
+ Revision: 1000776
- new version: 20160401
- compile code with -std=gnu++11
- new upstream URL and Source URL from github
- rediff symbols-fix patch

* Tue Apr 12 2016 daviddavid <daviddavid> 20131024-6.mga6
+ Revision: 1000750
- Mageiaify spec file
+ neoclust <neoclust>
- imported package re2

